pub struct Course {
pub id: u32,
pub name: String,
pub title: String,
pub description: Option<String>,
pub details_url: String,
pub unlock_url: String,
pub reviews_url: String,
pub comet_url: String,
pub spyware_urls: Vec<String>,
}Expand description
get /api/v8/core/org/{organization_slug}/courses
Fields
id: u32name: Stringtitle: Stringdescription: Option<String>details_url: String/api/v8/core/courses/{course_id}
unlock_url: String/api/v8/core/courses/{course_id}/unlock
reviews_url: String/api/v8/core/courses/{course_id}/reviews
comet_url: StringTypically empty.
spyware_urls: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Course
impl<'de> Deserialize<'de> for Course
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Course
impl JsonSchema for Course
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Course
impl RefUnwindSafe for Course
impl Send for Course
impl Sync for Course
impl Unpin for Course
impl UnwindSafe for Course