pub struct CourseData {Show 21 fields
pub name: String,
pub hide_after: Option<String>,
pub hidden: bool,
pub cache_version: Option<u32>,
pub spreadsheet_key: Option<String>,
pub hidden_if_registered_after: Option<String>,
pub refreshed_at: Option<DateTime<FixedOffset>>,
pub locked_exercise_points_visible: bool,
pub description: Option<String>,
pub paste_visibility: Option<u32>,
pub formal_name: Option<String>,
pub certificate_downloadable: Option<bool>,
pub certificate_unlock_spec: Option<String>,
pub organization_id: Option<u32>,
pub disabled_status: Option<String>,
pub title: Option<String>,
pub material_url: Option<String>,
pub course_template_id: Option<u32>,
pub hide_submission_results: bool,
pub external_scoreboard_url: Option<String>,
pub organization_slug: Option<String>,
}Expand description
get /api/v8/courses/{course_id} get /api/v8/org/{organization_slug}/courses/{course_name}
Fields
name: Stringhide_after: Option<String>cache_version: Option<u32>spreadsheet_key: Option<String>refreshed_at: Option<DateTime<FixedOffset>>locked_exercise_points_visible: booldescription: Option<String>paste_visibility: Option<u32>formal_name: Option<String>certificate_downloadable: Option<bool>certificate_unlock_spec: Option<String>organization_id: Option<u32>disabled_status: Option<String>title: Option<String>material_url: Option<String>Typically empty.
course_template_id: Option<u32>hide_submission_results: boolexternal_scoreboard_url: Option<String>Typically empty.
organization_slug: Option<String>Trait Implementations
Sourceimpl Debug for CourseData
impl Debug for CourseData
Sourceimpl<'de> Deserialize<'de> for CourseData
impl<'de> Deserialize<'de> for CourseData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CourseData
impl JsonSchema for CourseData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CourseData
impl RefUnwindSafe for CourseData
impl Send for CourseData
impl Sync for CourseData
impl Unpin for CourseData
impl UnwindSafe for CourseData