pub struct CourseExercise {
pub id: u32,
pub available_points: Vec<ExercisePoint>,
pub awarded_points: Vec<String>,
pub name: String,
pub publish_time: Option<String>,
pub solution_visible_after: Option<String>,
pub deadline: Option<String>,
pub soft_deadline: Option<String>,
pub disabled: bool,
pub unlocked: bool,
}Expand description
get /api/v8/courses/{course_id}/exercises
Fields
id: u32available_points: Vec<ExercisePoint>awarded_points: Vec<String>name: Stringpublish_time: Option<String>solution_visible_after: Option<String>deadline: Option<String>soft_deadline: Option<String>disabled: boolunlocked: boolTrait Implementations
Sourceimpl Debug for CourseExercise
impl Debug for CourseExercise
Sourceimpl<'de> Deserialize<'de> for CourseExercise
impl<'de> Deserialize<'de> for CourseExercise
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CourseExercise
impl JsonSchema for CourseExercise
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CourseExercise
impl RefUnwindSafe for CourseExercise
impl Send for CourseExercise
impl Sync for CourseExercise
impl Unpin for CourseExercise
impl UnwindSafe for CourseExercise