pub struct ExerciseDetails {
pub course_name: String,
pub course_id: u32,
pub code_review_requests_enabled: bool,
pub run_tests_locally_action_enabled: bool,
pub exercise_name: String,
pub exercise_id: u32,
pub unlocked_at: Option<String>,
pub deadline: Option<String>,
pub submissions: Vec<ExerciseSubmission>,
}Expand description
get /api/v8/core/exercises/{exercise_id}
Fields
course_name: Stringcourse_id: u32code_review_requests_enabled: boolrun_tests_locally_action_enabled: boolexercise_name: Stringexercise_id: u32unlocked_at: Option<String>deadline: Option<String>submissions: Vec<ExerciseSubmission>Trait Implementations
Sourceimpl Debug for ExerciseDetails
impl Debug for ExerciseDetails
Sourceimpl<'de> Deserialize<'de> for ExerciseDetails
impl<'de> Deserialize<'de> for ExerciseDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExerciseDetails
impl JsonSchema for ExerciseDetails
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExerciseDetails
impl RefUnwindSafe for ExerciseDetails
impl Send for ExerciseDetails
impl Sync for ExerciseDetails
impl Unpin for ExerciseDetails
impl UnwindSafe for ExerciseDetails