pub struct ExercisePoint {
pub id: u32,
pub exercise_id: u32,
pub name: String,
pub requires_review: bool,
}Fields
id: u32exercise_id: u32name: Stringrequires_review: boolTrait Implementations
Sourceimpl Debug for ExercisePoint
impl Debug for ExercisePoint
Sourceimpl<'de> Deserialize<'de> for ExercisePoint
impl<'de> Deserialize<'de> for ExercisePoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExercisePoint
impl JsonSchema for ExercisePoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExercisePoint
impl RefUnwindSafe for ExercisePoint
impl Send for ExercisePoint
impl Sync for ExercisePoint
impl Unpin for ExercisePoint
impl UnwindSafe for ExercisePoint