pub struct ExerciseSubmission {
pub exercise_name: String,
pub id: u32,
pub user_id: u32,
pub course_id: u32,
pub created_at: DateTime<FixedOffset>,
pub all_tests_passed: bool,
pub points: Option<String>,
pub submitted_zip_url: String,
pub paste_url: Option<String>,
pub processing_time: Option<u32>,
pub reviewed: bool,
pub requests_review: bool,
}Fields
exercise_name: Stringid: u32user_id: u32course_id: u32created_at: DateTime<FixedOffset>all_tests_passed: boolpoints: Option<String>submitted_zip_url: String/api/v8/core/submissions/{submission_id}/download
paste_url: Option<String>https://tmc.mooc.fi/paste/{paste_code}
processing_time: Option<u32>reviewed: boolrequests_review: boolTrait Implementations
Sourceimpl Debug for ExerciseSubmission
impl Debug for ExerciseSubmission
Sourceimpl<'de> Deserialize<'de> for ExerciseSubmission
impl<'de> Deserialize<'de> for ExerciseSubmission
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExerciseSubmission
impl JsonSchema for ExerciseSubmission
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExerciseSubmission
impl RefUnwindSafe for ExerciseSubmission
impl Send for ExerciseSubmission
impl Sync for ExerciseSubmission
impl Unpin for ExerciseSubmission
impl UnwindSafe for ExerciseSubmission