pub struct ExercisesDetails {
pub id: u32,
pub course_name: String,
pub exercise_name: String,
pub checksum: String,
pub hide_submission_results: bool,
}Fields
id: u32course_name: Stringexercise_name: Stringchecksum: Stringhide_submission_results: boolTrait Implementations
Sourceimpl Debug for ExercisesDetails
impl Debug for ExercisesDetails
Sourceimpl<'de> Deserialize<'de> for ExercisesDetails
impl<'de> Deserialize<'de> for ExercisesDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExercisesDetails
impl JsonSchema for ExercisesDetails
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExercisesDetails
impl RefUnwindSafe for ExercisesDetails
impl Send for ExercisesDetails
impl Sync for ExercisesDetails
impl Unpin for ExercisesDetails
impl UnwindSafe for ExercisesDetails