pub struct Organization {
pub name: String,
pub information: String,
pub slug: String,
pub logo_path: String,
pub pinned: bool,
}Expand description
get /api/v8/org.json get /api/v8/org/{organization_slug}.json
Fields
name: Stringinformation: Stringslug: Stringlogo_path: Stringpinned: boolTrait Implementations
Sourceimpl Debug for Organization
impl Debug for Organization
Sourceimpl<'de> Deserialize<'de> for Organization
impl<'de> Deserialize<'de> for Organization
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Organization
impl JsonSchema for Organization
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Organization
impl RefUnwindSafe for Organization
impl Send for Organization
impl Sync for Organization
impl Unpin for Organization
impl UnwindSafe for Organization