pub struct Review {
pub submission_id: u32,
pub exercise_name: String,
pub id: u32,
pub marked_as_read: bool,
pub reviewer_name: String,
pub review_body: String,
pub points: Vec<String>,
pub points_not_awarded: Vec<String>,
pub url: String,
pub update_url: String,
pub created_at: DateTime<FixedOffset>,
pub updated_at: DateTime<FixedOffset>,
}Expand description
get /api/v8/core/courses/{course_id}/reviews
Fields
submission_id: u32exercise_name: Stringid: u32marked_as_read: boolreviewer_name: Stringreview_body: Stringpoints: Vec<String>points_not_awarded: Vec<String>url: Stringhttps://tmc.mooc.fi/submissions/{submission_id}/reviews
update_url: String/api/v8/core/courses/{course_id}/reviews/{review_id}
created_at: DateTime<FixedOffset>updated_at: DateTime<FixedOffset>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Review
impl<'de> Deserialize<'de> for Review
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Review
impl JsonSchema for Review
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Review
impl RefUnwindSafe for Review
impl Send for Review
impl Sync for Review
impl Unpin for Review
impl UnwindSafe for Review