pub struct Submission {Show 24 fields
pub id: u32,
pub user_id: u32,
pub pretest_error: Option<String>,
pub created_at: DateTime<FixedOffset>,
pub exercise_name: String,
pub course_id: u32,
pub processed: bool,
pub all_tests_passed: bool,
pub points: Option<String>,
pub processing_tried_at: Option<DateTime<FixedOffset>>,
pub processing_began_at: Option<DateTime<FixedOffset>>,
pub processing_completed_at: Option<DateTime<FixedOffset>>,
pub times_sent_to_sandbox: u32,
pub processing_attempts_started_at: DateTime<FixedOffset>,
pub params_json: Option<String>,
pub requires_review: bool,
pub requests_review: bool,
pub reviewed: bool,
pub message_for_reviewer: String,
pub newer_submission_reviewed: bool,
pub review_dismissed: bool,
pub paste_available: bool,
pub message_for_paste: String,
pub paste_key: Option<String>,
}Expand description
get /api/v8/courses/{course_id}/submissions get /api/v8/courses/{course_id}/users/{user_id}/submissions get /api/v8/courses/{course_id}/users/current/submissions get api/v8/exercises/{exercise_id}/users/{user_id}/submissions get api/v8/exercises/{exercise_id}/users/current/submissions get /api/v8/org/{organization_slug}/courses/{course_name}/submissions get /api/v8/org/{organization_slug}/courses/{course_name}/users/{user_id}/submissions get /api/v8/org/{organization_slug}/courses/{course_name}/users/current/submissions get api/v8/exercises/{exercise_id}/users/{user_id}/submissions get api/v8/exercises/{exercise_id}/users/current/submissions
Fields
id: u32user_id: u32pretest_error: Option<String>created_at: DateTime<FixedOffset>exercise_name: Stringcourse_id: u32processed: boolall_tests_passed: boolpoints: Option<String>processing_tried_at: Option<DateTime<FixedOffset>>processing_began_at: Option<DateTime<FixedOffset>>processing_completed_at: Option<DateTime<FixedOffset>>times_sent_to_sandbox: u32processing_attempts_started_at: DateTime<FixedOffset>params_json: Option<String>requires_review: boolrequests_review: boolreviewed: boolmessage_for_reviewer: Stringnewer_submission_reviewed: boolreview_dismissed: boolpaste_available: boolmessage_for_paste: Stringpaste_key: Option<String>Trait Implementations
Sourceimpl Debug for Submission
impl Debug for Submission
Sourceimpl<'de> Deserialize<'de> for Submission
impl<'de> Deserialize<'de> for Submission
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Submission
impl JsonSchema for Submission
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Submission
impl RefUnwindSafe for Submission
impl Send for Submission
impl Sync for Submission
impl Unpin for Submission
impl UnwindSafe for Submission