pub struct SubmissionFeedbackQuestion {
pub id: u32,
pub question: String,
pub kind: SubmissionFeedbackKind,
}Fields
id: u32question: Stringkind: SubmissionFeedbackKindTrait Implementations
Sourceimpl Debug for SubmissionFeedbackQuestion
impl Debug for SubmissionFeedbackQuestion
Sourceimpl<'de> Deserialize<'de> for SubmissionFeedbackQuestion
impl<'de> Deserialize<'de> for SubmissionFeedbackQuestion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubmissionFeedbackQuestion
impl JsonSchema for SubmissionFeedbackQuestion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for SubmissionFeedbackQuestion
impl StructuralPartialEq for SubmissionFeedbackQuestion