pub struct SubmissionFeedbackResponse {
pub api_version: u32,
pub status: SubmissionStatus,
}Expand description
post /api/v8/core/submissions/{submission_id}/feedback
Fields
api_version: u32status: SubmissionStatusTrait Implementations
Sourceimpl Debug for SubmissionFeedbackResponse
impl Debug for SubmissionFeedbackResponse
Sourceimpl<'de> Deserialize<'de> for SubmissionFeedbackResponse
impl<'de> Deserialize<'de> for SubmissionFeedbackResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubmissionFeedbackResponse
impl JsonSchema for SubmissionFeedbackResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubmissionFeedbackResponse
impl RefUnwindSafe for SubmissionFeedbackResponse
impl Send for SubmissionFeedbackResponse
impl Sync for SubmissionFeedbackResponse
impl Unpin for SubmissionFeedbackResponse
impl UnwindSafe for SubmissionFeedbackResponse