pub struct TmcStyleValidationError {
pub column: u32,
pub line: u32,
pub message: String,
pub source_name: String,
}Expand description
A style validation error.
Fields
column: u32line: u32message: Stringsource_name: StringTrait Implementations
Sourceimpl Debug for TmcStyleValidationError
impl Debug for TmcStyleValidationError
Sourceimpl<'de> Deserialize<'de> for TmcStyleValidationError
impl<'de> Deserialize<'de> for TmcStyleValidationError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TmcStyleValidationError
impl JsonSchema for TmcStyleValidationError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TmcStyleValidationError
impl PartialEq for TmcStyleValidationError
Sourceimpl Serialize for TmcStyleValidationError
impl Serialize for TmcStyleValidationError
impl Eq for TmcStyleValidationError
impl StructuralPartialEq for TmcStyleValidationError